@@ -153,12 +153,20 @@ class InternalDialog(BuilderDialog):
         codename = get_dist()
         return di.is_lts(codename)
 
+    def _has_livepatch_settings_ui(self):
+        try:
+            return Gio.DesktopAppInfo \
+                .new('gnome-online-accounts-panel.desktop')
+        except Exception:
+            return None
+
     def on_livepatch_status_ready(self, active, cs, ps, fixes):
         self.set_desc(None)
 
         if not active:
             if self._is_livepatch_supported() and \
                self.settings_button and \
+               self._has_livepatch_settings_ui() and \
                self.settings.get_int('launch-count') >= 4:
                 self.set_desc(_("<b>Tip:</b> You can use Livepatch to "
                                 "keep your computer more secure between "
@@ -295,6 +303,22 @@ class UnsupportedDialog(DistUpgradeDialog):
         DistUpgradeDialog.run(self, parent)
 
 
+class NoUpgradeForYouDialog(InternalDialog):
+    def __init__(self, window_main, meta_release, arch):
+        InternalDialog.__init__(self, window_main)
+        self.set_header(_("Sorry, there are no more upgrades for this system"))
+        # Translators: this is an Ubuntu version name like "Ubuntu 12.04"
+        self.set_desc(_("\nThere will not be any further Ubuntu releases "
+                        "for this system's '%s' architecture.\n\n"
+                        "Updates for Ubuntu %s will continue until "
+                        "2023-04-26.\n\nIf you reinstall Ubuntu from "
+                        "ubuntu.com/download, future upgrades will "
+                        "be available.") %
+                       (arch, meta_release.current_dist_version))
+        self.focus_button = self.add_button(Gtk.STOCK_OK,
+                                            self.window_main.close)
+
+
 class PartialUpgradeDialog(InternalDialog):
     def __init__(self, window_main):
         InternalDialog.__init__(self, window_main)
