@@ -27,9 +27,9 @@ def run_hwe_command(option):
     elif sp.returncode == 10:
         res = out.strip()
     else:
-        res = (b'Error: command ' + str(command).encode() +
-               b' failed with exit code ' +
-               str(sp.returncode).encode() + b': ' + out)
+        res = (b'Error: command ' + str(command).encode()
+               + b' failed with exit code '
+               + str(sp.returncode).encode() + b': ' + out)
     return res
 
 
@@ -44,10 +44,11 @@ encountered when upgrading Ubuntu from one release to another?")
     if response:
         os.execlp('apport-bug', 'apport-bug', 'ubuntu-release-upgrader')
     else:
-        try:
+        package = report.get("Package", None)
+        if package:
+            package = package.split(' ')[0]
+        if package == 'update-manager':
             attach_gsettings_package(report, 'update-manager')
-        except:
-            pass
         attach_file_if_exists(report, '/var/log/apt/history.log',
                               'DpkgHistoryLog.txt')
         attach_file_if_exists(report, '/var/log/apt/term.log',
@@ -62,5 +63,6 @@ encountered when upgrading Ubuntu from one release to another?")
             unsupported = run_hwe_command('--show-all-unsupported')
             if unsupported:
                 report['HWEunsupported'] = unsupported
-                report['HWEreplacements'] = run_hwe_command('--show-replacements')
+                report['HWEreplacements'] = \
+                    run_hwe_command('--show-replacements')
         report["Aptdaemon"] = recent_syslog(re.compile("AptDaemon"))
