@@ -1,24 +1,25 @@
 #!/usr/bin/python3
 # -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
 
-import random
+import distro_info
+import glob
 import logging
 import multiprocessing
 import os
+import random
 import sys
 import tempfile
-import glob
+import time
+import unittest
 try:
     from test.support import EnvironmentVarGuard
 except ImportError:
-    from test.test_support import EnvironmentVarGuard
-import time
+    from test.support.os_helper import EnvironmentVarGuard
 try:
     from urllib.error import HTTPError
     from urllib.request import install_opener, urlopen
 except ImportError:
     from urllib2 import HTTPError, install_opener, urlopen
-import unittest
 
 from mock import patch
 
@@ -63,7 +64,7 @@ def get_new_dist(current_release):
     for hardy+1
     """
     meta = MetaReleaseCore()
-    #meta.DEBUG = True
+    # meta.DEBUG = True
     meta.current_dist_name = current_release
     fake_metarelease = os.path.join(CURDIR, "test-data",
                                     "meta-release")
@@ -176,11 +177,20 @@ class TestMetaReleaseCore(unittest.TestCase):
 
     def test_html_uri_real(self):
         # test parsing of a meta-releaes file from the server
+        di = distro_info.UbuntuDistroInfo()
+        ltses = [supported for supported in di.supported()
+                 if di.is_lts(supported)]
         with EnvironmentVarGuard() as environ:
-            environ["META_RELEASE_FAKE_CODENAME"] = "lucid"
+            environ["META_RELEASE_FAKE_CODENAME"] = ltses[-2]
             meta = MetaReleaseCore(forceDownload=True)
             while meta.downloading:
                 time.sleep(0.1)
+            # it's possible the next LTS is in development
+            if meta.new_dist is None:
+                meta = MetaReleaseCore(useDevelopmentRelease=True,
+                                       forceDownload=True)
+                while meta.downloading:
+                    time.sleep(0.1)
             self.assertIsNotNone(meta.new_dist)
             uri = meta.new_dist.releaseNotesHtmlUri
             f = urlopen(uri)
