@@ -50,8 +50,8 @@ class TestOriginMatcher(unittest.TestCase):
         test_pkgs = set()
         for pkg in self.cache:
             if pkg.candidate and pkg.candidate.origins:
-                if [l.archive for l in pkg.candidate.origins
-                        if l.archive == "xenial-security"]:
+                if [line.archive for line in pkg.candidate.origins
+                        if line.archive == "xenial-security"]:
                     test_pkgs.add(pkg.name)
         self.assertTrue(len(test_pkgs) > 0)
         ul = UpdateList(None, dist="xenial")
@@ -90,10 +90,10 @@ class TestOriginMatcher(unittest.TestCase):
                         if o.archive == "xenial-security":
                             had_security = True
                             break
-                if (is_in_updates and
-                        not is_in_security and
-                        had_security and
-                        len(pkg._pkg.version_list) > 2):
+                if (is_in_updates
+                        and not is_in_security
+                        and had_security
+                        and len(pkg._pkg.version_list) > 2):
                     test_pkgs.add(pkg.name)
         self.assertTrue(len(test_pkgs) > 0,
                         "no suitable test package found that has a version in "
